# python-renameat2 documentation

If you are looking for the code that builds the documentation, you're in the right place.

If you'd like to actually read the documentation, this directory will disappoint you. A readable version of the documentation is available at [ReadTheDocs](https://python-renameat2.readthedocs.io/en/latest/).
